searchData={"items":[{"type":"module","title":"O11y","doc":"A module to help with OpenTelemetry tracing.","ref":"O11y.html"},{"type":"function","title":"O11y.attach_distributed_trace_ctx/1","doc":"This is the counterpart to `get_distributed_trace_ctx/0`. It is used to \"extract\" trace context information from http headers.\nThis context information is stored in a string so it can be passed around by other means as well.\n\nExample:\n```elixir\niex> O11y.attach_distributed_trace_ctx([traceparent: \"00-0af7651916cd43dd8448eb211c80319c-b7ad6b7169203331-01\"])\niex> O11y.attach_distributed_trace_ctx(\"00-0af7651916cd43dd8448eb211c80319c-b7ad6b7169203331-01\")\niex> O11y.attach_distributed_trace_ctx(nil)\n```","ref":"O11y.html#attach_distributed_trace_ctx/1"},{"type":"function","title":"O11y.get_distributed_trace_ctx/0","doc":"This function is typically used to \"inject\" trace context information into http headers such that\nthe trace can be continued in another service. However, it can also be used to link span in cases where\nOpenTelemetry.Ctx.attach/1 will not work (such as when the parent span has already ended or been removed from the dictionary).\n\nExample:\n```elixir\niex> res = Tracer.with_span \"some_span\", do: O11y.get_distributed_trace_ctx()\niex> [{\"traceparent\", _}] = res\n```","ref":"O11y.html#get_distributed_trace_ctx/0"},{"type":"function","title":"O11y.record_exception/1","doc":"Records an exception and sets the status of the current span to error.\n\nExample:\n\n```elixir\niex> O11y.record_exception(%RuntimeError{message: \"something went wrong\"})\n%RuntimeError{message: \"something went wrong\"}\n```\n\nProduces a span like:\n```elixir\n{:span, 28221055821181380594370570739471883760, 5895012157721301439, [],\n  :undefined, \"checkout\", :internal, -576460751313205167, -576460751311430083,\n  {:attributes, 128, :infinity, 0, %{}},\n  {:events, 128, 128, :infinity, 0,\n  [\n    {:event, -576460751311694042, \"exception\",\n     {:attributes, 128, :infinity, 0,\n      %{\n        \"exception.message\": \"something went wrong\",\n        \"exception.stacktrace\": \"...\",\n        \"exception.type\": \"Elixir.RuntimeError\"\n      }}}\n  ]}, {:links, 128, 128, :infinity, 0, []}, {:status, :error, \"\"}, 1, false,\n  :undefined}\n```","ref":"O11y.html#record_exception/1"},{"type":"function","title":"O11y.set_attribute/2","doc":"Sets the given attribute on the current span. If the value is not a valid OTLP type,\nit will be converted to a string with `inspect`.\n\nThis method does not support structs to maps, regardless of whether the struct implements the O11y.SpanAttributes protocol.\nYou need to use `set_attributes/1` for that.\n\nExample:\n\n```elixir\niex> O11y.set_attribute(\"key\", \"value\")\n:ok\n```\n\nProduces span attributes like:\n```elixir\n{:attributes, 128, :infinity, 0, %{key: \"value\"}}\n```","ref":"O11y.html#set_attribute/2"},{"type":"function","title":"O11y.set_attributes/1","doc":"Adds the given attributes as a list, map, or struct to the current span.\nIf the value is a maps or struct, it will be converted to a list of key-value pairs.\nIf the struct derives the O11y.SpanAttributes protocol, it will honor the except and only options.\n\nExample:\n\n```elixir\niex> O11y.set_attributes(%{id: 123, name: \"Alice\"})\n%{id: 123, name: \"Alice\"}\n```\n\nProduces span attributes like:\n```elixir\n{:attributes, 128, :infinity, 0, %{id: 123, name: \"Alice\"}}\n```","ref":"O11y.html#set_attributes/1"},{"type":"function","title":"O11y.set_attributes/2","doc":"Same as set_attributes/1, but with a prefix for all keys.\n\nExample:\n\n```elixir\niex> O11y.set_attributes(\"user\", %{name: \"Steve\", age: 47})\n%{name: \"Steve\", age: 47}\n```\n\nProduces span attributes like:\n```elixir\n{:attributes, 128, :infinity, 0, %{\"user.age\" => 47, \"user.name\" => \"Steve\"}}\n```","ref":"O11y.html#set_attributes/2"},{"type":"function","title":"O11y.set_error/0","doc":"Sets the status of the current span to error","ref":"O11y.html#set_error/0"},{"type":"function","title":"O11y.set_error/1","doc":"Sets the status of the current span to error, and sets an error attribute","ref":"O11y.html#set_error/1"},{"type":"protocol","title":"O11y.SpanAttributes","doc":"Defines a protocol for returning opentelemetry span attributes from an object.\nThe easiest way to use this is to use the `@derive` attribute on a struct as shown below,\nbut you can also implement the protocol manually if you need to define custom behavior.\n\nWith the basic derive, all fields in the struct will be returned as attributes:\n```elixir\ndefmodule Basic do\n  @derive O11y.SpanAttributes\n  defstruct [:id, :name]\nend\n```\n\nYou can also use the `only` and `except` options to include or exclude specific fields:\n```elixir\ndefmodule Only do\n  @derive {O11y.SpanAttributes, only: [:id, :name]}\n  defstruct [:id, :name, :email, :password]\nend\n```\n\n```elixir\ndefmodule Except do\n  @derive {O11y.SpanAttributes, except: [:email, :password]}\n  defstruct [:id, :name, :email, :password]\nend\n```\n\nOr you can manually implement the protocol for a struct:\n```elixir\ndefmodule Fancy do\n  defstruct [:url, :token]\nend\n\ndefimpl O11y.SpanAttributes, for: Fancy do\n  def get(%{url: url, token: token}) do\n    masked_token = token |> String.slice(-4, 4) |> String.pad_leading(String.length(token), \"*\")\n    [{\"url\", url}, {\"token\", masked_token}]\n  end\nend\n```","ref":"O11y.SpanAttributes.html"},{"type":"function","title":"O11y.SpanAttributes.get/1","doc":"Returns the opentelemetry span attributes for the given object as a list of tuples.","ref":"O11y.SpanAttributes.html#get/1"},{"type":"type","title":"O11y.SpanAttributes.t/0","doc":"All the types that implement this protocol.","ref":"O11y.SpanAttributes.html#t:t/0"},{"type":"behaviour","title":"O11y.TestHelper","doc":"Provides a few helper functions to make testing with OpenTelemetry easier.\n\nExample:\n\n```elixir\ndefmodule MyTest do\n  use ExUnit.Case, async: true\n  use O11y.TestHelper\n\n  test \"appends the given attribute to the span\" do\n    Tracer.with_span \"checkout\" do\n      O11y.set_attribute(:id, 123)\n    end\n\n    assert_span(\"checkout\", attributes: %{id: 123})\n  end\nend\n```","ref":"O11y.TestHelper.html"},{"type":"callback","title":"O11y.TestHelper.assert_span/2","doc":"Asserts that a span with the given name was exported and optionally checks the status and attributes.\n\nExample:\n```elixir\nassert_span(\"checkout\", attributes: %{\"id\" => 123})\nassert_span(\"checkout\", status: :error)\n```\n\nIt returns the matched span record so you can make additional assertions. The easiest way is to pattern match by creating a span record and bind the properties you want to assert on.\nYou can use the included span, link, and event records to help with this, as well as the status, links, events, and attributes functions.\n\nExamples:\n```elixir\nspan(status: status, events: events) = assert_span(\"checkout\")\n\nassert status(status) == :error\nassert [event(name: \"exception\", attributes: attributes)] = events(events)\nassert %{\"exception.message\": \"something went wrong\"} = attributes(attributes)\n```","ref":"O11y.TestHelper.html#c:assert_span/2"},{"type":"callback","title":"O11y.TestHelper.attributes/1","doc":"Extracts the attributes from a span record as a map.","ref":"O11y.TestHelper.html#c:attributes/1"},{"type":"callback","title":"O11y.TestHelper.events/1","doc":"Extracts the events from a span record. Individual event records can be further inspected with the `event` function.","ref":"O11y.TestHelper.html#c:events/1"},{"type":"callback","title":"O11y.TestHelper.links/1","doc":"Extracts the links from a span record. Individual link records can be further inspected with the `link` function.","ref":"O11y.TestHelper.html#c:links/1"},{"type":"callback","title":"O11y.TestHelper.otel_pid_reporter/1","doc":"Sets up OpenTelemetry to use the pid exporter and ensures it is stopped after the test.\nWhen spans are exported, a message is sent to the test pid allowing you to `assert_receive` on a tuple with the span.\n\nThis is already setup for you when you `use O11y.TestHelper`.\n```elixir\nsetup [:otel_pid_reporter]\n```","ref":"O11y.TestHelper.html#c:otel_pid_reporter/1"},{"type":"callback","title":"O11y.TestHelper.status/1","doc":"Extracts the status atom from the status field on a span record.","ref":"O11y.TestHelper.html#c:status/1"},{"type":"type","title":"O11y.TestHelper.span_record/0","doc":"","ref":"O11y.TestHelper.html#t:span_record/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}